@@ -666,7 +666,7 @@ bool Setpastixmpi()
 
 
 
-Init init;
+LOADINIT(Init);
 Init::Init()
 { 
   
