@@ -7,7 +7,7 @@
 // AUTHOR   : Guy Atenekeng
 // E-MAIL   : Guy_Antoine_Atenekeng_Kahou@lri.fr
 //
-//ff-c++-LIBRARY-dep: metis parms  blas mpifc 
+//ff-c++-LIBRARY-dep: metis parms  blas mpifc fc
 //ff-c++-cpp-dep: 
 
 /* 
@@ -1024,7 +1024,7 @@ bool SetdSolvePARMS()
      TypeSolveMat::defaultvalue  = TypeSolveMatdefaultvalue;
      return TRUE;
 }
-Init init;
+LOADINIT(Init);
 Init::Init()
 { 
   
