@@ -1046,6 +1046,14 @@ FESpace::FESpace(const FESpace ** Vh,int k )
 {
      if(cdef) renum();
     Show();
+    // verification 
+    long snbdf=0;
+    for(int i=0;i<k;++i)
+        snbdf += Vh[i]->NbOfDF;
+    if( snbdf !=NbOfDF)
+        cerr << " Problem build of FEspace (2d) (may be : due to periodic Boundary condition missing ) FH " << endl
+             << " The number of DF must be " << snbdf << "  and it is " << NbOfDF <<endl; 
+    ffassert(snbdf == NbOfDF );
 }
      
 FESpace::FESpace(const Mesh & TTh,const TypeOfFE ** tef,int k,int nbdfv,const int *ndfv,int nbdfe,const int *ndfe )
