@@ -222,6 +222,7 @@ AnyType FWhile(Stack s ,Expression test,Expression ins)
         if(sptrclean) sptrclean=sptr->clean(); // modif FH mars 2006  clean Ptr
        if (e.code == E_exception::e_break) break;
        else if  (e.code == E_exception::e_continue) continue;
+       else throw e;
        }
   return a;
 }
@@ -243,6 +244,7 @@ AnyType FFor(Stack s ,Expression i0,Expression i1,Expression i2,Expression ins)
         if(sptrclean) sptrclean=sptr->clean(); // modif FH mars 2006  clean Ptr
        if (e.code == E_exception::e_break) break;
        else if  (e.code == E_exception::e_continue) continue;
+       else throw e;
        }
    }
   return a;
@@ -781,7 +783,16 @@ inline double walltime(){
 
 long atoi(string* p) {return atoi(p->c_str());}// add march 2010
 double atof(string* p) {return atof(p->c_str());}// add march 2010
+double NaN(string* p) {return nan(p->c_str());}// add march 2012
+double NaN() {return nan("");}// add march 2012
 
+long isNaN(double x){return isnan(x);}
+long isInf(double x){return isinf(x);}
+long isNormal(double x){return isnormal(x);}
+//int  ShowAlloc(const char *s, size_t lg);
+int ShowAlloc(const char *s,size_t & lg); 
+long ShowAlloc1(string *  s,long * np) { size_t lg; long  n= ShowAlloc(s->c_str(),lg); *np=lg; return n;}
+long ShowAlloc1(string *  s) { size_t lg; long  n= ShowAlloc(s->c_str(),lg); return n;}
 void Init_map_type()
 {
    TheOperators=new Polymorphic(), 
@@ -1356,7 +1367,16 @@ void Init_map_type()
   Global.Add("randres53","(",new OneOperator_0<double>(genrand_res53));
   Global.Add("randinit","(",new OneOperator1<long>(genrandint));
   
-       
+   //  NaN and Inf 
+  Global.Add("ShowAlloc","(",new OneOperator1<long,string*>(ShowAlloc1));// debuging 
+  Global.Add("ShowAlloc","(",new OneOperator2<long,string*,long*>(ShowAlloc1));// debuging 
+  Global.Add("NaN","(",new OneOperator0<double>(NaN));
+  Global.Add("NaN","(",new OneOperator1<double,string*   >(NaN));
+    Global.Add("isNaN","(",new OneOperator1<long,double>(isNaN));
+    Global.Add("isInf","(",new OneOperator1<long,double>(isInf));
+    Global.Add("isNormal","(",new OneOperator1<long,double>(isNormal));
+ 
+  
 
 typedef MyMap<String,String> MyMapSS;
     
@@ -1373,7 +1393,7 @@ typedef MyMap<String,String> MyMapSS;
   
 
 }
-int ShowAlloc(const char *s,size_t & lg); 
+//int ShowAlloc(const char *s,size_t & lg); 
 
 
 
@@ -1516,7 +1536,7 @@ C_F0  opDot::code2(const basicAC_F0 &args) const
 	};
     if( na1==1 && mb1 ==1)
 	return C(0,0);
-    else if (( mb1 ==1) ) // || (na1==1)) // correct du car ' on conj encore r . mars 2010 
+    else if ( mb1 ==1 ) // || (na1==1)) // correct du car ' on conj encore r . mars 2010 
     {
 	AC_F0  v;
 	v=C(0,0);
