@@ -224,7 +224,29 @@ KN_<K> fSubArray(const KN_<K> & a,const SubArray & b)
 template<class K>  
 KN_<K> fSubArrayp( KN<K>  * const & a,const SubArray & b)
  { return (*a)(b);}
- 
+
+template<class K>  
+KNM_<K> fSubArraybb(const KNM_<K> & a,const SubArray & b,const SubArray & c)
+{ return a(b,c);}
+template<class K>  
+KNM_<K> fSubArraypbb( KNM<K> * const & a,const SubArray & b,const SubArray & c)
+{ return (*a)(b,c);}
+
+template<class K>  
+KN_<K> fSubArrayib(const KNM_<K> & a,const long &i,const SubArray & b)
+{ return a(i,b);}
+template<class K>  
+KN_<K> fSubArraybi(const KNM_<K> & a,const SubArray & b,const long &i)
+{ return a(b,i);}
+
+template<class K>  
+KN_<K> fSubArraypib( KNM<K> *const & a,const long &i,const SubArray & b)
+{ return (*a)(i,b);}
+template<class K>  
+KN_<K> fSubArraypbi( KNM<K> *const & a,const SubArray & b,const long &i)
+{ return (*a)(b,i);}
+
+
 template<class A>  
 A fSubArrayc(const A & a,const char & b)
  { return a;}
@@ -616,7 +638,7 @@ void ArrayDCL()
  
     //Dcl_Type<KN<K> *>(0,::Destroy<KN<K> >,   ::ClearReturnpKK<K,KN<K> > );
     //Dcl_TypeandPtr<KN_<K> >(0,0,0,0,::ClearReturnKK_<K,KN<K>,KN_<K> >,::ClearReturnpKK_<K,KN<K>,KN_<K> >);
-    Dcl_TypeandPtr_<KN_<K> ,KN<K>*  > (0,0,0,::Destroy<KN<K> >, ::ClearReturnKK_<K,KN<K>,KN_<K> >,::ClearReturnpKK<K,KN<K> >);
+    Dcl_TypeandPtr_<KN_<K> ,KN<K>*  > (0,0,::InitP<KN<K> >,::Destroy<KN<K> >, ::ClearReturnKK_<K,KN<K>,KN_<K> >,::ClearReturnpKK<K,KN<K> >); // add init 0
     
     //  Dcl_Type<KN<Complex> *>(0,::Destroy<KN<Complex> >);
    // Dcl_Type<KN<K> *>(0,::Destroy<KN<K> >); // Modif 17102005 
@@ -624,7 +646,9 @@ void ArrayDCL()
 
   //  Dcl_Type<KNM<K> *>(0,::Destroy<KNM<K> > ,::ClearReturnpKK<K,KNM<K> >);
     Dcl_TypeandPtr_<KNM_<K> ,KNM<K>*  > (0,0,0,::Destroy<KNM<K> >, ::ClearReturnKK_<K,KNM<K>,KNM_<K> >,::ClearReturnpKK<K,KNM<K> >);
-
+    Dcl_Type<  KN<KNM<K> >* >();
+    Dcl_Type<  KN<KN<K> >* >();
+    
     Dcl_Type< outProduct_KN_<K>* >();
     Dcl_Type< Transpose<KN_<K> > > ();
     Dcl_Type< Transpose< KNM<K> *> >();
@@ -672,7 +696,10 @@ void ArrayDCL()
        ); */
     map_type_of_map[make_pair(atype<long>(),atype<K>())]=atype<KN<K>*>(); // vector
     map_pair_of_type[make_pair(atype<long>(),atype<long>())] =atype<pair<long,long> >();   
-    map_type_of_map[make_pair(atype<pair<long,long> >(),atype<K>())]=atype<KNM<K>*>(); // matrix                                               
+    map_type_of_map[make_pair(atype<pair<long,long> >(),atype<K>())]=atype<KNM<K>*>(); // matrix 
+    map_type_of_map[make_pair(atype<long>(),atype<KN_<K> >())]=atype<KN<KN<K> >*>();// tableau de tableau
+    map_type_of_map[make_pair(atype<long>(),atype<KNM_<K> >())]=atype<KN<KNM<K> >*>();// tableau de matrix 
+
 }
 
 
@@ -896,7 +923,18 @@ void ArrayOperator()
      atype<KN_<K> >()->Add("(","",new OneOperator2_<KN_<K>,KN_<K>,SubArray>(fSubArray<K> ));
      atype<KN<K>*>()->Add("(","",new OneOperator2_<KN_<K>,KN<K>*,SubArray>(fSubArrayp<K> ));
      atype<KN<K>* >()->Add("(","",new OneOperator2_<KN<K>*,KN<K>*,char >(fSubArrayc<KN<K>* >));
-
+// 
+    
+     atype<KNM_<K> >()->Add("(","",new OneOperator3_<KNM_<K>,KNM_<K>,SubArray,SubArray>(fSubArraybb<K> ));
+     atype<KNM<K>* >()->Add("(","",new OneOperator3_<KNM_<K>,KNM<K>*,SubArray,SubArray>(fSubArraypbb<K> ));
+    /*
+     atype<KN_<K> >()->Add("(","",new OneOperator3_<KN_<K>,KNM_<K>,SubArray,long>(fSubArraybi<K> ));
+     atype<KN_<K> >()->Add("(","",new OneOperator3_<KN_<K>,KNM_<K>,long,SubArray>(fSubArrayib<K> ));
+     atype<KN_<K> >()->Add("(","",new OneOperator3_<KN_<K>,KNM<K>*,SubArray,long>(fSubArraypbi<K> ));
+     atype<KN_<K> >()->Add("(","",new OneOperator3_<KN_<K>,KNM<K>*,long,SubArray>(fSubArraypib<K> ));
+     */
+//
+    
     atype<KN_<K> >()->Add("[","",new OneOperator2_<K*,KN_<K>,Z >(get_element_<K,KN_<K>,Z>));
     atype<KN_<K> >()->Add("(","",new OneOperator2_<K*,KN_<K>,Z >(get_element_<K,KN_<K>,Z>));
     
@@ -961,6 +999,7 @@ void ArrayOperator()
      Add<Resize<KN<K> > >("(","",new OneOperator2_<KN<K> *,Resize<KN<K> > , Z   >(resize1));
      Add<Resize<KNM<K> > >("(","",new OneOperator3_<KNM<K> *,Resize<KNM<K> > , Z, Z  >(resize2));
 
+    
      TheOperators->Add("<-", 
        new OneOperator2_<KN<K> *,KN<K> *,Z>(&set_init),
        new InitArrayfromArray<K,true>
@@ -968,6 +1007,11 @@ void ArrayOperator()
     //   new OneOperator2_<KN<K> *,KN<K> *,KN_<K> >(&set_init)		????       
      //  new OneOperator2_<KN<K> *,KN<K> *,KN<K> * >(&set_initp)
        );
+    TheOperators->Add("<-", 
+                      new OneOperator2_<KN< KN<K> > *,KN< KN<K> > * ,Z  >(&set_init));
+    TheOperators->Add("<-", 
+                      new OneOperator2_<KN< KNM<K> > *,KN< KNM<K> > * ,Z  >(&set_init));
+    
      TheOperators->Add("<-", 
         new OneOperator3_<KNM<K> *,KNM<K> *,Z,Z>(&set_init2),
         new InitMatfromAArray<K,true>
@@ -994,7 +1038,19 @@ void ArrayOperator()
      Add<KN<K> *>("n",".",new OneOperator1<Z,KN<K> *>(get_n));
      Add<KNM<K> *>("n",".",new OneOperator1<Z,KNM<K> *>(get_n));
      Add<KNM<K> *>("m",".",new OneOperator1<Z,KNM<K> *>(get_m));
-     
+ //ajout ars 2012 FH    
+     Add<KN<KN<K> > *>("n",".",new OneOperator1<long,KN<KN<K> > *>(get_n));     
+     Add<KN<KNM<K> > *>("n",".",new OneOperator1<long,KN<KNM<K> > *>(get_n));  
+     atype<KN<KN<K> > * >()->Add("[","",new OneOperator2_<KN<K>*,KN<KN<K> >*,Z >(get_elementp_<KN<K>,KN<KN<K> >*,Z>));
+    atype<KN<KNM<K> > * >()->Add("[","",new OneOperator2_<KNM<K>*,KN<KNM<K> >*,Z >(get_elementp_<KNM<K>,KN<KNM<K> >*,Z>));
+    Dcl_Type< Resize<KN<KN<K> > > > ();
+    Dcl_Type< Resize<KN<KNM<K> > > >();
+    Add<KN<KN<K> > * >("resize",".",new OneOperator1< Resize<KN<KN<K> > >,KN<KN<K> > *>(to_Resize));
+    Add<KN<KNM<K> > * >("resize",".",new OneOperator1< Resize<KN<KNM<K> > >,KN<KNM<K> > *>(to_Resize));
+    Add<Resize<KN<KN<K> > > >("(","",new OneOperator2_<KN<KN<K> >  *,Resize<KN<KN<K> > > , long   >(resize1));
+    Add<Resize<KN<KNM<K> > > >("(","",new OneOperator2_<KN<KNM<K> >  *,Resize<KN<KNM<K> > > , long   >(resize1));
+    
+    
 //     AddOpeqarray<set_eqarray,KN,K>("=");
 
      TheOperators->Add("=", new InitArrayfromArray<K,false>
@@ -1003,7 +1059,7 @@ void ArrayOperator()
        );
      TheOperators->Add("=", new SetArrayofKNfromKN<K>
        );
- if(0)    
+ if(0) //  a  change il faut regle un PB ambiguite ...  
      TheOperators->Add("=",
         new OneBinaryOperator<set_eqarray<KN<K> ,K > > ,
         new OneBinaryOperator<set_eqarray<KN<K> ,Add_KN_<K> > > ,
@@ -1140,7 +1196,8 @@ void ArrayOperator()
       );*/
  
       TheOperators->Add("*=",
-        new OneBinaryOperator<set_eq_array_mul<KN_<K> ,K > >  ,
+                        new OneBinaryOperator<set_eq_array_mul<KN_<K> ,K > >  );
+     TheOperators->Add(".*=",
         new OneBinaryOperator<set_eq_array_mul<KN_<K> ,Add_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_mul<KN_<K> ,Sub_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_mul<KN_<K> ,Mulc_KN_<K> > > ,
@@ -1162,7 +1219,8 @@ void ArrayOperator()
      );*/
 
      TheOperators->Add("/=",
-        new OneBinaryOperator<set_eq_array_div<KN_<K> ,K > > ,
+                       new OneBinaryOperator<set_eq_array_div<KN_<K> ,K > > );
+    TheOperators->Add("./=",
         new OneBinaryOperator<set_eq_array_div<KN_<K> ,Add_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_div<KN_<K> ,Sub_KN_<K> > > ,
         new OneBinaryOperator<set_eq_array_div<KN_<K> ,Mulc_KN_<K> > > ,
@@ -1272,7 +1330,11 @@ void ArrayOperator()
        new OneBinaryOperator<Print<KNM_<K> > >,
        new OneBinaryOperator<Print<KN_<K> > >
        ); 
-     
+    TheOperators->Add("<<",
+                      new OneBinaryOperator< PrintPnd< KN< KNM<K> >* > >,
+                      new OneBinaryOperator< PrintPnd< KN< KN<K> >* > >
+                      ); 
+    
        
      TheOperators->Add(">>",
         new OneBinaryOperator<Op_ReadKN<K> >
@@ -1292,6 +1354,7 @@ void ArrayOperator()
 		      new OneTernaryOperator3<SetArray3<K> >);
     TheOperators->Add("<-", 
 		      new OneOperator2_<KN<K> *,KN<K> *,SetArray<K> >(&set_init_array));
+ 
     TheOperators->Add("=", 
 		      new OneOperator2_<KN<K> *,KN<K> *,SetArray<K> >(&set_array),
 		      new OneOperator2_<KN<K> *,KN<K> *,KN<K> * >(&set_arrayp),  //  to reomve ambiguity aug 2009
