@@ -1018,11 +1018,7 @@ struct Op_Allgather : public binary_function<KN_<R>,KN_<R>,long> {
       int mpisizew;
       MPI_Comm_size(comm, &mpisizew); /* local */ 
       int chunk = r.N()/mpisizew;
-      if( ! 	     (r.N()==mpisizew*chunk && chunk*mpisizew==s.N()) )
-	{
-	  cout << " ???? Error size buf  r.N " << r.N() << " s.N = " << s.N() << " mpisizew " << mpisizew << endl; 
-	  ffassert(r.N()==mpisizew*chunk && chunk*mpisizew==s.N());
-	}
+      ffassert(r.N()==mpisizew*chunk && chunk == s.N());
       return MPI_Allgather( (void *) (R*) s, chunk, MPI_TYPE<R>::TYPE(),
 			    (void *) (R*) r, chunk, MPI_TYPE<R>::TYPE(), comm);	
     }
@@ -1214,7 +1210,7 @@ struct Op_Scatter1 : public   ternary_function<KN_<R>, R* ,MPIrank,long> {
     int mpisizew;
     MPI_Comm_size(root.comm, &mpisizew); 
     int chunk = 1;
-    ffassert(s.N()==mpisizew*chunk);
+   // ffassert(s.N()==mpisizew*chunk);
     
     return MPI_Scatter( (void *) (R*) s, chunk, MPI_TYPE<R>::TYPE(),
 			(void *) (R*) r, chunk, MPI_TYPE<R>::TYPE(),root.who,root.comm);	
@@ -1235,8 +1231,8 @@ struct Op_Scatter3 : public   ternary_function<KN_<R>,KN_<R>,MPIrank,long> {
 
     int mpisizew;
     MPI_Comm_size(root.comm, &mpisizew); 
-    int chunk = s.N()/mpisizew;
-    ffassert(s.N()==mpisizew*chunk && r.N()==chunk);
+    int chunk = r.N(); // FH  correct  jan 2012 ... 
+    // ffassert(s.N()==mpisizew*chunk && r.N()==chunk);
     
     return MPI_Scatter( (void *) (R*) s, chunk, MPI_TYPE<R>::TYPE(),
 			(void *) (R*) r, chunk, MPI_TYPE<R>::TYPE(),root.who,root.comm);	
@@ -1257,14 +1253,14 @@ long Op_Scatterv3( KN_<R>  const  & s, KN_<R>  const  &r,  MPIrank const & root,
   
   int mpisizew;
   MPI_Comm_size(root.comm, &mpisizew); /* local */ 
-  ffassert( sendcnts.N() == displs.N() && sendcnts.N() == mpisizew );
+ //  ffassert( sendcnts.N() == displs.N() && sendcnts.N() == mpisizew );
   // size control 
-  ffassert( r.N() == sendcnts[mpirankv] );
+ // ffassert( r.N() == sendcnts[mpirankv] );
   long sumsize=0;
   for(int ii=0; ii<sendcnts.N(); ii++){
     sumsize += sendcnts[ii];
   }
-  ffassert( s.N() == sumsize );
+ // ffassert( s.N() == sumsize );
   
   KN<int> INTsendcnts(sendcnts.N());
   KN<int> INTdispls(displs.N());
@@ -1391,10 +1387,11 @@ struct Op_Gather1 : public   ternary_function<R*,KN_<R>,MPIrank,long> {
     static long  f(Stack, R* const  & s, KN_<R>  const  &r,  MPIrank const & root)  
   { 
     
-    int mpisizew;
+    int mpisizew,myrank;
     MPI_Comm_size(root.comm, &mpisizew); 
+    MPI_Comm_rank( root.comm, &myrank)  ;
     int chunk = 1;
-    ffassert(r.N()==mpisizew*chunk );
+    // ffassert( (myrank != root.who) || (r.N()>=mpisizew*chunk) );
     
     return MPI_Gather( (void *) (R*) s, chunk, MPI_TYPE<R>::TYPE(),
 			   (void *) (R*) r, chunk, MPI_TYPE<R>::TYPE(),root.who,root.comm);	
@@ -1410,11 +1407,13 @@ struct Op_Gather3 : public   ternary_function<KN_<R>,KN_<R>,MPIrank,long> {
   { 
       CheckContigueKN(r);
       CheckContigueKN(s);
+      int mpisizew,myrank;
+      MPI_Comm_size(root.comm, &mpisizew); 
+      MPI_Comm_rank(root.comm, &myrank)  ;
 
-    int mpisizew;
-    MPI_Comm_size(root.comm, &mpisizew); 
-    int chunk = r.N()/mpisizew;
-    ffassert(r.N()==mpisizew*chunk && chunk*mpisizew==s.N());
+    int chunk = s.N();
+    //  cout << myrank << " " << root.who << " " << r.N() << " "<< s.N() << " " << chunk << " " << mpisizew << endl;
+    //ffassert( (myrank != root.who) || (r.N()==mpisizew*chunk) );
     
     return MPI_Gather( (void *) (R*) s, chunk, MPI_TYPE<R>::TYPE(),
 			   (void *) (R*) r, chunk, MPI_TYPE<R>::TYPE(),root.who,root.comm);	
@@ -1435,13 +1434,13 @@ long  Op_Gatherv3(KN_<R>  const  & s, KN_<R>  const  &r,  MPIrank const & root,
   MPI_Comm_rank(root.comm, &mpirankw); 
   int mpisizew;
   MPI_Comm_size(root.comm, &mpisizew); 
-  ffassert( recvcount.N() == displs.N() && recvcount.N() == mpisizew);
+ // ffassert( recvcount.N() == displs.N() && recvcount.N() == mpisizew);  fait dans mpi.. 
   
   if( mpirankw == root.who){
     long sum=0;
     for(int ii=0; ii< recvcount.N(); ii++)
       sum+=recvcount[ii];
-    ffassert( sum == r.N() );
+   // ffassert( sum == r.N() );
   }
   KN<int> INTrecvcount(recvcount.N());
   KN<int> INTdispls(displs.N());
@@ -1774,7 +1773,7 @@ struct Op_Scatter1<Complex> : public   ternary_function<KN_<Complex>,Complex *,M
     int mpisizew;
     MPI_Comm_size(root.comm, &mpisizew); 
     int chunk = 1;
-    ffassert(s.N()==mpisizew*chunk );
+    // ffassert(s.N()==mpisizew*chunk ); fait dans mpi
 #ifdef HAVE_MPI_DOUBLE_COMPLEX      
     return MPI_Scatter( (void *) (Complex*)s, chunk, MPI_DOUBLE_COMPLEX,
 			(void *) (Complex*)r, chunk, MPI_DOUBLE_COMPLEX,root.who,root.comm);	
@@ -1796,8 +1795,8 @@ struct Op_Scatter3<Complex> : public   ternary_function<KN_<Complex>,KN_<Complex
 
     int mpisizew;
     MPI_Comm_size(root.comm, &mpisizew); 
-    int chunk = s.N()/mpisizew;
-    ffassert(s.N()==mpisizew*chunk && r.N()==chunk);
+    int chunk = r.N();// correct 2012 FH
+   // ffassert(s.N()==mpisizew*chunk && r.N()==chunk);
 #ifdef HAVE_MPI_DOUBLE_COMPLEX      
     return MPI_Scatter( (void *) (Complex*)s, chunk, MPI_DOUBLE_COMPLEX,
 			(void *) (Complex*)r, chunk, MPI_DOUBLE_COMPLEX,root.who,root.comm);	
@@ -1822,14 +1821,14 @@ long Op_Scatterv3<Complex>( KN_<Complex>  const  & s, KN_<Complex>  const  &r,
   
   int mpisizew;
   MPI_Comm_size(root.comm, &mpisizew); /* local */ 
-  ffassert( sendcnts.N() == displs.N() && sendcnts.N() == mpisizew );
+  //  ffassert( sendcnts.N() == displs.N() && sendcnts.N() == mpisizew );
   // size control 
-  ffassert( r.N() == sendcnts[mpirankv] );
+  // ffassert( r.N() == sendcnts[mpirankv] );
   long sumsize=0;
   for(int ii=0; ii<sendcnts.N(); ii++){
     sumsize += sendcnts[ii];
   }
-  ffassert( s.N() == sumsize );
+  //ffassert( s.N() == sumsize );
   
   KN<int> INTsendcnts(sendcnts.N());
   KN<int> INTdispls(displs.N());
@@ -1925,12 +1924,14 @@ struct Op_Gather1<Complex> : public   ternary_function<Complex* ,KN_<Complex>,MP
       CheckContigueKN(r);
       
 
-    int mpisizew;
-    MPI_Comm_size(root.comm, &mpisizew); 
+      int mpisizew,myrank;
+      MPI_Comm_size(root.comm, &mpisizew); 
+      MPI_Comm_rank( root.comm, &myrank)  ;
+      
     int chunk = 1;
-    ffassert(r.N()==mpisizew*chunk );
+   // ffassert( (myrank != root.who) || (r.N()>=mpisizew*chunk) );
 #ifdef HAVE_MPI_DOUBLE_COMPLEX  
-   
+       
     return MPI_Gather( (void *) (Complex*) s, chunk, MPI_DOUBLE_COMPLEX,
 			   (void *) (Complex*) r, chunk, MPI_DOUBLE_COMPLEX, root.who, root.comm);
 #else
@@ -1951,11 +1952,14 @@ struct Op_Gather3<Complex> : public   ternary_function<KN_<Complex>,KN_<Complex>
       CheckContigueKN(r);
       CheckContigueKN(s);
 
-    int mpisizew;
-    MPI_Comm_size(root.comm, &mpisizew); 
-    int chunk = r.N()/mpisizew;
-    ffassert(r.N()==mpisizew*chunk && chunk==s.N());
-#ifdef HAVE_MPI_DOUBLE_COMPLEX     
+      int mpisizew,myrank;
+      MPI_Comm_size(root.comm, &mpisizew); 
+      MPI_Comm_rank( root.comm, &myrank)  ;
+
+    int chunk = s.N();
+    // ffassert( (myrank != root.who) || (r.N()>=mpisizew*chunk) );
+#ifdef HAVE_MPI_DOUBLE_COMPLEX    
+       
     return MPI_Gather( (void *) (Complex*)s, chunk, MPI_DOUBLE_COMPLEX,
 			   (void *) (Complex*)r, chunk, MPI_DOUBLE_COMPLEX,root.who,root.comm);	
 #else
@@ -1978,7 +1982,7 @@ long  Op_Gatherv3<Complex>(KN_<Complex>  const  & s, KN_<Complex>  const  &r,  M
   MPI_Comm_rank(root.comm, &mpirankw); 
   int mpisizew;
   MPI_Comm_size(root.comm, &mpisizew); 
-  ffassert( recvcount.N() == displs.N() && recvcount.N() == mpisizew);
+  //ffassert((mpirankw != root.who) || ( recvcount.N() == displs.N() && recvcount.N() == mpisizew));
   
   if( mpirankw == root.who){
     long sum=0;
@@ -2247,7 +2251,7 @@ AnyType ClearReturnKK_(Stack stack, const AnyType & a)
 }
 //template<class RR,class A,class B>  fMPI_Request*,KN<MPI_Request>*,long
 fMPI_Request * get_elementp_( KN<MPI_Request> * const & a,const long & b){ 
-  if( b<0 || a->N() <= b) 
+  if( a==0 || b<0 || a->N() <= b) 
     { cerr << " Out of bound  0 <=" << b << " < "  << a->N() << " KN<MPI_Request> * " << endl;
       ExecError("Out of bound in operator []");}
   return  reinterpret_cast<fMPI_Request *> (&((*a)[b]));}// bofBof ... 
